@@ -1,5 +1,5 @@
 /*
-% Copyright (C) 2003 - 2009 GraphicsMagick Group
+% Copyright (C) 2003 - 2015 GraphicsMagick Group
 % Copyright (C) 2002 ImageMagick Studio
 % Copyright 1991-1999 E. I. du Pont de Nemours and Company
 %
@@ -136,6 +136,13 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
                            image->filename);
         }
     }
+
+  if (image->logging)
+    (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+			  "Tile %lux%lu%+ld%+ld",
+			  image->tile_info.width,image->tile_info.height,
+			  image->tile_info.x,image->tile_info.y);
+
   /*
     Allocate memory for a scanline.
   */
@@ -153,8 +160,8 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
       image->matte=True;
       packet_size=(quantum_size*5)/8;
     }
-  scanline=MagickAllocateMemory(unsigned char *,
-    packet_size*image->tile_info.width);
+  scanline=MagickAllocateArray(unsigned char *,
+			       packet_size,image->tile_info.width);
   if (scanline == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,MemoryAllocationFailed,image);
   /*
@@ -640,7 +647,7 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
   packet_size=(quantum_size*4)/8;
   if (LocaleCompare(image_info->magick,"CMYKA") == 0)
     packet_size=(quantum_size*5)/8;
-  pixels=MagickAllocateMemory(unsigned char *,packet_size*image->columns);
+  pixels=MagickAllocateArray(unsigned char *,packet_size,image->columns);
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,MemoryAllocationFailed,image);
   if (image_info->interlace != PartitionInterlace)
@@ -861,10 +868,9 @@ static unsigned int WriteCMYKImage(const ImageInfo *image_info,Image *image)
           }
         if (image_info->interlace == PartitionInterlace)
           (void) strlcpy(image->filename,image_info->filename,MaxTextExtent);
-        if (!MagickMonitorFormatted(400,400,&image->exception,
-                                    SaveImageText,image->filename,
-				    image->columns,image->rows))
-          break;
+        (void) MagickMonitorFormatted(400,400,&image->exception,
+                                      SaveImageText,image->filename,
+                                      image->columns,image->rows);
         break;
       }
     }
